Improve this Doc View Source

Specify custom behavior on keyup event.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as element:

      <ng-keyup
        ng-keyup="expression">
      ...
      </ng-keyup>

- as attribute:

      <ANY
        ng-keyup="expression">
      ...
      </ANY>

### Arguments

Param | Type | Details
--- | --- | ---
ngKeyup | expression | Expression to evaluate upon keyup. (Event object is available as `$event` and can be interrogated for keyCode, altKey, etc.)

## Examples

    <p>Typing in the input box below updates the key count</p>
    <input ng-keyup="count = count + 1" ng-init="count=0"> key up count: {{count}}

    <p>Typing in the input box below updates the keycode</p>
    <input ng-keyup="event=$event">
    <p>event keyCode: {{ event.keyCode }}</p>
    <p>event altKey: {{ event.altKey }}</p>